# NuvIoT Python Libaries

Set of libraries that can be used to accessed data generated from IoT devices and captured with NuvIoT.

To access your data, please create a client application within NuvIoT to generate an application id and authorization token.